summaryrefslogtreecommitdiff
path: root/sources/scalac/symtab/EntryTags.java
diff options
context:
space:
mode:
authorMartin Odersky <odersky@gmail.com>2003-07-31 09:57:59 +0000
committerMartin Odersky <odersky@gmail.com>2003-07-31 09:57:59 +0000
commit03449ed20a3cca9e8d974c7efeff6b4e01ecb66d (patch)
treedb1153ac4bffac098d6d6d053f727992f1a2e4da /sources/scalac/symtab/EntryTags.java
parentbe21ca1267f48e8fd14d5e32f3c7a4d814005eef (diff)
downloadscala-03449ed20a3cca9e8d974c7efeff6b4e01ecb66d.tar.gz
scala-03449ed20a3cca9e8d974c7efeff6b4e01ecb66d.tar.bz2
scala-03449ed20a3cca9e8d974c7efeff6b4e01ecb66d.zip
*** empty log message ***
Diffstat (limited to 'sources/scalac/symtab/EntryTags.java')
-rw-r--r--sources/scalac/symtab/EntryTags.java76
1 files changed, 37 insertions, 39 deletions
diff --git a/sources/scalac/symtab/EntryTags.java b/sources/scalac/symtab/EntryTags.java
index b8ae7c2d7a..ed1d089641 100644
--- a/sources/scalac/symtab/EntryTags.java
+++ b/sources/scalac/symtab/EntryTags.java
@@ -14,24 +14,23 @@ public interface EntryTags {
* Symbol table attribute format:
* Symtab = nentries_Nat {Entry}
* Entry = 1 TERMNAME len_Nat NameInfo
* | 2 CONSTRNAME len_Nat NameInfo
* | 3 TYPENAME len_Nat NameInfo
* | 4 NONEsym len_Nat
* | 5 TYPEsym len_Nat SymbolInfo lobound_Ref
* | 6 ALIASsym len_Nat SymbolInfo
* | 7 CLASSsym len_Nat SymbolInfo thistype_Ref constrsym_Ref
* | 8 VALsym len_Nat SymbolInfo [classsym_Ref]
* | 9 EXTsym len_Nat name_Ref [owner_Ref]
* | 10 EXTMODCLASSsym len_Nat name_Ref [owner_Ref]
* | 11 NOtpe len_Nat
* | 12 THIStpe len_Nat sym_Ref
* | 13 SINGLEtpe len_Nat type_Ref sym_Ref
* | 14 TYPEREFtpe len_Nat type_Ref sym_Ref {targ_Ref}
* | 15 COMPOUNDtpe len_Nat classsym_Ref {tpe_Ref}
* | 16 METHODtpe len_Nat tpe_Ref {tpe_Ref}
* | 17 POLYTtpe len_Nat tpe_Ref {sym_Ref}
* | 18 OVERLOADEDtpe len_Nat {sym_Ref} {tpe_Ref}
* | 21 FLAGGEDtype len_Nat flags_Nat tpe_Ref
* SymbolInfo = name_Ref owner_Ref flags_Nat info_Ref
* NameInfo = <character sequence of length len_Nat in Utf8 format>
* Ref = Nat
@@ -40,27 +39,26 @@ public interface EntryTags {
*/
int TERMname = 1,
- CONSTRname = 2,
- TYPEname = 3,
- NONEsym = 4,
- TYPEsym = 5,
- ALIASsym = 6,
- CLASSsym = 7,
- VALsym = 8,
- EXTsym = 9,
- EXTMODCLASSsym = 10,
- NOtpe = 11,
- THIStpe = 12,
- SINGLEtpe = 13,
- TYPEREFtpe = 14,
- COMPOUNDtpe = 15,
- METHODtpe = 16,
- POLYtpe = 17,
- OVERLOADEDtpe = 18,
- UNBOXEDtpe = 19,
- UNBOXEDARRAYtpe = 20,
- FLAGGEDtpe = 21,
- ERRORtpe = 22;
+ TYPEname = 2,
+ NONEsym = 3,
+ TYPEsym = 4,
+ ALIASsym = 5,
+ CLASSsym = 6,
+ VALsym = 7,
+ TERMref = 8,
+ TYPEref = 9,
+ NOtpe = 10,
+ THIStpe = 11,
+ SINGLEtpe = 12,
+ TYPEREFtpe = 13,
+ COMPOUNDtpe = 14,
+ METHODtpe = 15,
+ POLYtpe = 16,
+ OVERLOADEDtpe = 17,
+ UNBOXEDtpe = 18,
+ UNBOXEDARRAYtpe = 19,
+ FLAGGEDtpe = 20,
+ ERRORtpe = 21;
int firstSymTag = NONEsym, lastSymTag = VALsym;
int firstTypeTag = NOtpe, lastTypeTag = FLAGGEDtpe;
@@ -14,24 +14,23 @@ public interface EntryTags {
* Symtab = nentries_Nat {Entry}
* Entry = 1 TERMNAME len_Nat NameInfo
- * | 2 CONSTRNAME len_Nat NameInfo
- * | 3 TYPENAME len_Nat NameInfo
- * | 4 NONEsym len_Nat
- * | 5 TYPEsym len_Nat SymbolInfo lobound_Ref
- * | 6 ALIASsym len_Nat SymbolInfo
- * | 7 CLASSsym len_Nat SymbolInfo thistype_Ref constrsym_Ref
- * | 8 VALsym len_Nat SymbolInfo [classsym_Ref]
- * | 9 EXTsym len_Nat name_Ref [owner_Ref]
- * | 10 EXTMODCLASSsym len_Nat name_Ref [owner_Ref]
- * | 11 NOtpe len_Nat
- * | 12 THIStpe len_Nat sym_Ref
- * | 13 SINGLEtpe len_Nat type_Ref sym_Ref
- * | 14 TYPEREFtpe len_Nat type_Ref sym_Ref {targ_Ref}
- * | 15 COMPOUNDtpe len_Nat classsym_Ref {tpe_Ref}
- * | 16 METHODtpe len_Nat tpe_Ref {tpe_Ref}
- * | 17 POLYTtpe len_Nat tpe_Ref {sym_Ref}
- * | 18 OVERLOADEDtpe len_Nat {sym_Ref} {tpe_Ref}
- * | 21 FLAGGEDtype len_Nat flags_Nat tpe_Ref
+ * | 2 TYPENAME len_Nat NameInfo
+ * | 3 NONEsym len_Nat
+ * | 4 TYPEsym len_Nat SymbolInfo lobound_Ref
+ * | 5 ALIASsym len_Nat SymbolInfo
+ * | 6 CLASSsym len_Nat SymbolInfo thistype_Ref constrsym_Ref
+ * | 7 VALsym len_Nat SymbolInfo [classsym_Ref]
+ * | 8 TERMref len_Nat name_Ref [owner_Ref]
+ * | 9 TYPEref len_Nat name_Ref [owner_Ref]
+ * | 10 NOtpe len_Nat
+ * | 11 THIStpe len_Nat sym_Ref
+ * | 12 SINGLEtpe len_Nat type_Ref sym_Ref
+ * | 13 TYPEREFtpe len_Nat type_Ref sym_Ref {targ_Ref}
+ * | 14 COMPOUNDtpe len_Nat classsym_Ref {tpe_Ref}
+ * | 15 METHODtpe len_Nat tpe_Ref {tpe_Ref}
+ * | 16 POLYTtpe len_Nat tpe_Ref {sym_Ref}
+ * | 17 OVERLOADEDtpe len_Nat {sym_Ref} {tpe_Ref}
+ * | 20 FLAGGEDtype len_Nat flags_Nat tpe_Ref
* SymbolInfo = name_Ref owner_Ref flags_Nat info_Ref
* NameInfo = <character sequence of length len_Nat in Utf8 format>